# -*- coding: utf-8 -*-

from launchpadlib.launchpad import Launchpad
from launchpadlib.errors import HTTPError
from launchpadlib.launchpad import EDGE_SERVICE_ROOT

from teams.models import *
from django.conf import settings

import os
import sys

def is_debug_user(username):
    try:
        if settings.DEBUG and username in settings.DEBUG_USERS:
            return True
    except AttributeError:
        return False
    return False

def lp_login(lp_instance=EDGE_SERVICE_ROOT):
    cachedir = os.path.join(settings.PROJECT_PATH, 'lp_data/cache')
    client_ident = getattr(settings, 'LP_PROJECT_NAME', "LoCo Directory")
    try:
        launchpad = Launchpad.login_anonymously(client_ident, lp_instance, cachedir)
    except:
        try:
            # Support for launchpadlib pre 1.5.4.
            launchpad = Launchpad.login(client_ident, "", "", lp_instance, cachedir)
        except:
            # Launchpad might be offline.
            return None
    return launchpad

def is_user_on_loco_council(user):
    if not user.is_authenticated():
        return False
    if is_debug_user(user.username):
        return True
    lc_in_groups = user.groups.filter(name__exact='ubuntu-lococouncil')
    return (lc_in_groups.count() == 1)

def is_team_member(user, team):
    if not user.is_authenticated():
        return False
    if is_debug_user(user.username):
        return True
    user_in_groups = user.groups.filter(name__exact=team.lp_name)
    return (user_in_groups.count() >= 1)

def is_admin_or_owner(username, team):
    # check just using the LD data
    if username == team.owner:
        return True
    if team.admins.filter(lpid=username):
        return True
    if is_debug_user(username):
        return True
    # more complicated check :-/
    lp = lp_login()
    if not lp:
        return False
    try:
        lp_team = lp.people[team.lp_name]
    except:
        print >> sys.stderr, 'Something went wrong.'
        return False
    if lp_team.team_owner.is_team:
        if filter(lambda a: a.name == username, lp_team.team_owner.members):
            return True
    return False

def get_mugshot_url(lp, identity):
    # Not ideal, but until LP #336943
    # or similar, we are in a hard spot.
    # When this bug is fixed, this can be made cleaner.
    try:
       lp.people[identity].mugshot.open()
       return "https://edge.launchpad.net/api/beta/~%s/mugshot" % (identity)
    except HTTPError:
       # 404 or some other issue that means we should default to False
       return "https://edge.launchpad.net/api/beta/ubuntu/mugshot"
