import email
import os
from copy import deepcopy

def flat_list(some_list):
    """
    >>> reduce(lambda a,b: a.extend(b) or a, [[2,3],[6],[66,34]])
    [2, 3, 6, 66, 34]
    """
    if not some_list:
        return []
    return reduce(lambda a,b: a.extend(b) or a, some_list)
    

def redirect(to, *args, **kwargs):
    from distutils.version import LooseVersion as V
    import django
    if V(django.get_version()) > V('1.1'):
        from django.shortcuts import redirect as red
    else:
        from shortcuts import redirect as red

    return red(to, *args, **kwargs)


def get_locodirectory_version(version_file, debug):
    """
    return the bzr revision number and version of the LoCo Directory
    """

    if not os.path.exists(version_file):
        return "version unknown"

    f = email.message_from_file(open(version_file))
    version = f["version"]
    bzr_revno = f["revno"]
    
    if debug:
        try:
            from bzrlib.branch import Branch
            branch = Branch.open_containing('.')[0]
            bzr_revno = branch.revno()
        except:
            pass

    return "version %s (rev %s)" % (version, bzr_revno)

class simple_iterator(object):

    def __init__(self, *args):
        self.values = []
        self.index = -1
        if len(args) == 1 and isinstance(args[0], (list, tuple, set)):
            self.values.extend(deepcopy(args[0]))
        else:
            self.values.extend(deepcopy(args))
    
    def get_next_index(self):
        if self.index + 1 >= len(self.values):
            self.index = 0
        else:
            self.index = self.index + 1
        return self.index
    next_index = property(get_next_index)

    def get_next(self):
        return self.values[self.next_index]
    next = property(get_next)

    def reset(self):
        self.index = -1
        return ''
            
