
from south.db import db
from django.db import models
from events.models import *

class Migration:
    
    def forwards(self, orm):
        
        # Adding model 'BaseEvent'
        db.create_table('events_baseevent', (
            ('id', orm['events.BaseEvent:id']),
            ('name', orm['events.BaseEvent:name']),
            ('date_begin', orm['events.BaseEvent:date_begin']),
            ('date_end', orm['events.BaseEvent:date_end']),
            ('description', orm['events.BaseEvent:description']),
            ('announce', orm['events.BaseEvent:announce']),
            ('date_created', orm['events.BaseEvent:date_created']),
        ))
        db.send_create_signal('events', ['BaseEvent'])
        
        # Adding model 'TeamEvent'
        db.create_table('events_teamevent', (
            ('baseevent_ptr', orm['events.TeamEvent:baseevent_ptr']),
            ('global_event', orm['events.TeamEvent:global_event']),
            ('venue', orm['events.TeamEvent:venue']),
        ))
        db.send_create_signal('events', ['TeamEvent'])
        
        # Adding model 'GlobalEvent'
        db.create_table('events_globalevent', (
            ('baseevent_ptr', orm['events.GlobalEvent:baseevent_ptr']),
            ('microbloghashtag', orm['events.GlobalEvent:microbloghashtag']),
            ('pictag', orm['events.GlobalEvent:pictag']),
        ))
        db.send_create_signal('events', ['GlobalEvent'])
        
        # Adding model 'TeamEventComment'
        db.create_table('events_teameventcomment', (
            ('id', orm['events.TeamEventComment:id']),
            ('team_event', orm['events.TeamEventComment:team_event']),
            ('date_created', orm['events.TeamEventComment:date_created']),
            ('comment_by', orm['events.TeamEventComment:comment_by']),
            ('comment', orm['events.TeamEventComment:comment']),
        ))
        db.send_create_signal('events', ['TeamEventComment'])
        
        # Adding model 'Attendee'
        db.create_table('events_attendee', (
            ('id', orm['events.Attendee:id']),
            ('team_event', orm['events.Attendee:team_event']),
            ('attendee', orm['events.Attendee:attendee']),
            ('promise', orm['events.Attendee:promise']),
            ('guests', orm['events.Attendee:guests']),
        ))
        db.send_create_signal('events', ['Attendee'])
        
        # Adding ManyToManyField 'TeamEvent.teams'
        db.create_table('events_teamevent_teams', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('teamevent', models.ForeignKey(orm.TeamEvent, null=False)),
            ('team', models.ForeignKey(orm['teams.Team'], null=False))
        ))
        
        # Creating unique_together for [team_event, attendee] on Attendee.
        db.create_unique('events_attendee', ['team_event_id', 'attendee_id'])
        
    
    
    def backwards(self, orm):
        
        # Deleting unique_together for [team_event, attendee] on Attendee.
        db.delete_unique('events_attendee', ['team_event_id', 'attendee_id'])
        
        # Deleting model 'BaseEvent'
        db.delete_table('events_baseevent')
        
        # Deleting model 'TeamEvent'
        db.delete_table('events_teamevent')
        
        # Deleting model 'GlobalEvent'
        db.delete_table('events_globalevent')
        
        # Deleting model 'TeamEventComment'
        db.delete_table('events_teameventcomment')
        
        # Deleting model 'Attendee'
        db.delete_table('events_attendee')
        
        # Dropping ManyToManyField 'TeamEvent.teams'
        db.delete_table('events_teamevent_teams')
        
    
    
    models = {
        'auth.group': {
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'unique_together': "(('content_type', 'codename'),)"},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'unique_together': "(('app_label', 'model'),)", 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'events.attendee': {
            'Meta': {'unique_together': "(('team_event', 'attendee'),)"},
            'attendee': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"}),
            'guests': ('django.db.models.fields.PositiveSmallIntegerField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'promise': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'team_event': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['events.TeamEvent']"})
        },
        'events.baseevent': {
            'announce': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'date_begin': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True'}),
            'date_created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2010, 2, 4, 0, 38, 13, 583247)', 'db_index': 'True'}),
            'date_end': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '150'})
        },
        'events.globalevent': {
            'baseevent_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['events.BaseEvent']", 'unique': 'True', 'primary_key': 'True'}),
            'microbloghashtag': ('django.db.models.fields.CharField', [], {'max_length': '50', 'null': 'True', 'blank': 'True'}),
            'pictag': ('django.db.models.fields.CharField', [], {'max_length': '50', 'null': 'True', 'blank': 'True'})
        },
        'events.teamevent': {
            'baseevent_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['events.BaseEvent']", 'unique': 'True', 'primary_key': 'True'}),
            'global_event': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['events.GlobalEvent']", 'null': 'True', 'blank': 'True'}),
            'teams': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['teams.Team']", 'db_index': 'True'}),
            'venue': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['venues.Venue']", 'null': 'True', 'blank': 'True'})
        },
        'events.teameventcomment': {
            'comment': ('django.db.models.fields.TextField', [], {'db_index': 'True'}),
            'comment_by': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"}),
            'date_created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2010, 2, 4, 0, 38, 13, 587465)', 'db_index': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'team_event': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['events.TeamEvent']"})
        },
        'teams.team': {
            'Meta': {'db_table': "'teams'"},
            'admins': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['teams.TeamAdministrator']"}),
            'approved': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'approved_date': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'city': ('django.db.models.fields.CharField', [], {'max_length': '50', 'null': 'True', 'blank': 'True'}),
            'country': ('django.db.models.fields.CharField', [], {'max_length': '50', 'null': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'null': 'True', 'blank': 'True'}),
            'expires_date': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'forum_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'irc_chan': ('django.db.models.fields.CharField', [], {'max_length': '25', 'null': 'True', 'blank': 'True'}),
            'lp_name': ('django.db.models.fields.SlugField', [], {'max_length': '40', 'null': 'True', 'db_index': 'True'}),
            'ml_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'mugshot_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '80', 'null': 'True'}),
            'owner': ('django.db.models.fields.SlugField', [], {'max_length': '50', 'null': 'True', 'db_index': 'True'}),
            'provides_support': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'spr': ('django.db.models.fields.CharField', [], {'max_length': '50', 'null': 'True', 'blank': 'True'}),
            'web_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'wiki_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'})
        },
        'teams.teamadministrator': {
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'lpid': ('django.db.models.fields.SlugField', [], {'max_length': '40', 'db_index': 'True'})
        },
        'venues.venue': {
            'address': ('django.db.models.fields.CharField', [], {'max_length': '150', 'null': 'True', 'blank': 'True'}),
            'city': ('django.db.models.fields.CharField', [], {'max_length': '150', 'null': 'True', 'blank': 'True'}),
            'comment': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'country': ('django.db.models.fields.CharField', [], {'max_length': '150', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'latitude': ('django.db.models.fields.FloatField', [], {'null': 'True', 'blank': 'True'}),
            'longitude': ('django.db.models.fields.FloatField', [], {'null': 'True', 'blank': 'True'}),
            'map_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '150'}),
            'venue_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'})
        }
    }
    
    complete_apps = ['events']
