#!/usr/bin/python

from django.core.management.base import NoArgsCommand

from common import launchpad
from teams import models
from django.contrib.auth.models import Group

from datetime import datetime
import sys

def update_admins(ld_team, lp_team):
    ld_admin_names = set([a.lpid for a in ld_team.admins.all()])
    lp_admin_names = set([a.name for a in lp_team.getMembersByStatus(status='Administrator')])
    for admin_name in ld_admin_names.difference(lp_admin_names):
        admin = ld_team.admins.get(lpid=admin_name)
        admin.delete()
    for admin_name in lp_admin_names.difference(ld_admin_names):
        admin = models.TeamAdministrator(lpid=admin_name)
        admin.save()
        ld_team.admins.add(admin)


class Command(NoArgsCommand):
    help = "Pull list of LoCo Teams from Launchpad and add them to the DB."

    def handle_noargs(self, **options):
        lp = launchpad.lp_login()
        if not lp:
            sys.exit(1)
        TEAM_BLACKLIST = (u"ubuntu-lococouncil", u"ubuntu-games-merged")
        
        existing_locos = models.Team.objects.all()
        existing_groups = Group.objects.all()
        locos = filter(lambda a: a.is_team and a.name not in TEAM_BLACKLIST, 
                       lp.people["locoteams"].members)
        for l in locos:
            if not existing_locos or l.name not in [b.lp_name for b in existing_locos]:
                team = models.Team(lp_name=l.name, name=l.display_name, owner=l.team_owner.name)
                team.save()
            else:
                team = filter(lambda a: a.lp_name == l.name, existing_locos)[0]
                team.name = l.display_name
                team.owner = l.team_owner.name
            update_admins(team, l)
                
            if not existing_groups or l.name not in [g.name for g in existing_groups]:
                group = Group(name=l.name)
                group.save()
            approved_entry = filter(lambda a: a.team.name == u"locoteams-approved", l.memberships_details)
            if approved_entry:
                team.approved = True
                if team.approved:
                    approval = approved_entry[0]
                    if isinstance(approval.date_expires, unicode):
                        try:
                            team.expires_date = datetime.strptime(approval.date_expires[:19], "%Y-%m-%dT%H:%M:%S")
                        except ValueError:
                            team.expires_date = datetime.strptime(approval.date_expires[:11], "%Y-%m-%d")
                    else:
                        team.expires_date = approval.date_expires
            else:
                team.approved = False
                team.expires_date = None
            team.mugshot_url = launchpad.get_mugshot_url(lp, l.name)
            team.save()
