from django.db import models
from django.utils.translation import ugettext_lazy as _

from common.utils import flat_list

class Language(models.Model):
    class Meta:
        ordering = ('name',)
    name = models.CharField(_("Language"), max_length=150, null=True)
    code = models.CharField(_("Language Code"), max_length=20, null=True)

    def __unicode__(self):
        return u'%s' % (self.name)

class TeamManager(models.Manager):
    pass

class TeamAdministrator(models.Model):
    lpid = models.SlugField(_("Launchpad ID"), max_length=40, null=False, blank=False)
    def __unicode__(self):
       return u'%s' % (self.lpid)

class Continent(models.Model):
    name = models.TextField(_("Name"), max_length=50)
    
    def __unicode__(self):
        return u'%s' % (self.name)

    @property
    def related_countries(self):
        return self.country_set.all()

    @property
    def related_venues(self):
        return flat_list([list(a.related_venues) for a in self.related_countries])
    
    @property
    def related_teams(self):
        return flat_list([list(a.related_teams) for a in self.related_countries])

class Country(models.Model):
    name = models.TextField(_("Name"), max_length=100)
    continents = models.ManyToManyField(Continent)
    
    def __unicode__(self):
        return u'%s' % (self.name)

    @property
    def related_teams(self):
        return self.team_set.all()
    
    @property
    def related_venues(self):
        return self.venue_set.all()

def countries_without_continent():
    return Country.objects.filter(continents__isnull=True)

def countries_without_continent_have_venues():
    list_of_venues = [list(a.related_venues) for a in countries_without_continent()]
    return len(flat_list(list_of_venues))>0

def countries_without_continent_have_teams():
    list_of_teams = [list(a.related_teams) for a in countries_without_continent()]
    return len(flat_list(list_of_teams))>0

class Team(models.Model):
    lp_name = models.SlugField(_("Launchpad Team ID"), max_length=40, null=True)
    name = models.CharField(_("Team Name"), max_length=80, null=True)
    countries = models.ManyToManyField(Country)
    spr = models.CharField(_("State/Province/Region"), max_length=50, null=True, blank=True)
    city = models.CharField(_("City"), max_length=50, null=True, blank=True)
    wiki_url = models.URLField(_("Ubuntu Wiki Page"), verify_exists=False, null=True, blank=True)
    web_url = models.URLField(_("Website"), verify_exists=False, null=True, blank=True)
    ml_url = models.URLField(_("Mailing List URL"), verify_exists=False, null=True, blank=True)
    forum_url = models.URLField(_("Forums URL"), verify_exists=False, null=True, blank=True)
    email = models.EmailField(_("Email Address"), null=True, blank=True)
    irc_chan = models.CharField(_("IRC Channel"),
                                max_length=25, null=True, blank=True,
                                help_text=_("IRC Channel name that is hosted on "
                                "the freenode IRC network. Ex. #ubuntu-chicago"))
    provides_support = models.BooleanField(_("Provides local support"),
                                           default=True)
    approved = models.BooleanField(_("Approved Team"), default=False)
    approved_date = models.DateField(_("Date Approved"), null=True, blank=True)
    expires_date = models.DateField(_("Date Expires"), null=True, blank=True)
    owner = models.SlugField(_("Launchpad Team Owner"), null=True, blank=False)
    admins = models.ManyToManyField(TeamAdministrator)
    mugshot_url = models.URLField(_("URL of mugshot"), verify_exists=False, null=True, blank=True)
    languages = models.ManyToManyField(Language)
    
    objects = TeamManager()
    
    class Meta:
        db_table = 'teams'
        ordering = ('approved', 'name',)
        
    def __unicode__(self):
        return self.lp_name
   
    @models.permalink
    def get_absolute_url(self):
        return ('team-detail', [str(self.lp_name)])

def teams_without_country():
    return Team.objects.filter(countries__isnull=True)
