# -*- coding: utf-8 -*-

from django import forms
from django.utils.translation import ugettext_lazy as _
from models import Venue

def validate_name(name):
    if not name or not name.strip():
        raise forms.ValidationError(_(u'Please use a descriptive name for the venue.'))
    return name

class VenueForm(forms.ModelForm):
    """ 
    a form to create/update a new Venue
    """
    class Meta:
        model = Venue

    def clean(self):
        self.cleaned_data['name'] = validate_name(self.cleaned_data['name'])
        return super(VenueForm, self).clean()

class VenueSearchForm(forms.Form):
    """
    A Search form for venues
    """
    q = forms.CharField(label=_('Search'), required=False, max_length=100)

    def as_line(self):
        "Returns this form rendered. Only the fields. Nothing else HTML."
        return self._html_output(u'%(label)s %(errors)s%(field)s%(help_text)s', u'%s', '', u'%s', False)

