from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.db.models import permalink

from teams.models import Country

class VenueManager(models.Manager):
    """
    a manager class for Venues
    """
    pass 

class Venue(models.Model):
    """
    a venue
    """
    name = models.CharField(help_text=_('Name of the Venue'), max_length=150)
    country = models.ForeignKey(Country, null=True)
    city = models.CharField(help_text=_('City Name'), max_length=150, null=True, blank=True)
    address = models.CharField(help_text=_('Address with Street and Number'), max_length=150, null=True, blank=True)
    longitude = models.FloatField(help_text=_('Longitude in Degrees East'), null=True, blank=True)
    latitude = models.FloatField(help_text=_('Latitude in Degrees North'), null=True, blank=True)
    venue_url = models.URLField(help_text=_('URL for the Venue Homepage'), verbose_name=_('URL of the Venue'), max_length=200, verify_exists=False, blank=True, null=True)
    comment = models.TextField(help_text=_('Comment about the Venue'), blank=True, null=True)
    
    class Meta:
        unique_together = ( ('name', 'country', 'city'), ('longitude', 'latitude'), )

    #add manager 
    objects = VenueManager()

    def __unicode__(self):
        if self.city and self.country:
            return '%(name)s (%(city)s, %(country)s)' %{'name':self.name, 'city':self.city, 'country':self.country}
        else:
            return self.name
    
    @models.permalink
    def get_absolute_url(self):
        """ get the absolute url for the venue """
        return ('venue-detail', [self.id])

def venues_without_country():
    return Venue.objects.filter(country__isnull=True)
